# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: motionSL.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='motionSL.proto',
  package='motion_spec',
  syntax='proto2',
  serialized_pb=_b('\n\x0emotionSL.proto\x12\x0bmotion_spec\"h\n\x19VelAndAccConstraintValues\x12\x0c\n\x04vMax\x18\x01 \x02(\x01\x12\x0c\n\x04\x61Max\x18\x02 \x02(\x01\x12\x10\n\x08omegaMax\x18\x03 \x01(\x01\x12\x0f\n\x07\x61lfaMax\x18\x04 \x01(\x01\x12\x0c\n\x04jMax\x18\x05 \x01(\x01\">\n\x1aTimeAndAccConstraintValues\x12\x12\n\nT_duration\x18\x01 \x02(\x01\x12\x0c\n\x04\x61Max\x18\x02 \x02(\x01\"C\n\x1eTimeAndTimeAccConstraintValues\x12\x12\n\nT_duration\x18\x01 \x02(\x01\x12\r\n\x05T_acc\x18\x02 \x02(\x01\"\x85\x02\n\x10MotionConstraint\x12/\n\x04type\x18\x01 \x02(\x0e\x32!.motion_spec.MOTIONCONSTRAINTTYPE\x12@\n\x0btime_values\x18\x02 \x01(\x0b\x32+.motion_spec.TimeAndTimeAccConstraintValues\x12?\n\x0etimeacc_values\x18\x03 \x01(\x0b\x32\'.motion_spec.TimeAndAccConstraintValues\x12=\n\rvelacc_values\x18\x04 \x01(\x0b\x32&.motion_spec.VelAndAccConstraintValues\"W\n\x12WayPointConstraint\x12\x31\n\x04type\x18\x01 \x02(\x0e\x32#.motion_spec.WAYPOINTCONSTRAINTTYPE\x12\x0e\n\x06\x66\x61\x63tor\x18\x02 \x02(\x01\"?\n\tCartPose6\x12\x13\n\x0b\x63oordinates\x18\x01 \x03(\x01\x12\n\n\x02id\x18\x02 \x01(\r\x12\x11\n\tid_parent\x18\x03 \x01(\r\"\x1c\n\x05Twist\x12\x13\n\x0b\x63oordinates\x18\x01 \x03(\x01\"D\n\x0eJointPositions\x12\x13\n\x0b\x63oordinates\x18\x01 \x03(\x01\x12\n\n\x02id\x18\x02 \x01(\r\x12\x11\n\tid_parent\x18\x03 \x01(\r\"&\n\x0fJointVelocities\x12\x13\n\x0b\x63oordinates\x18\x01 \x03(\x01\"u\n\rToolTipOffset\x12\x0f\n\x07offsetX\x18\x01 \x02(\x01\x12\x0f\n\x07offsetY\x18\x02 \x02(\x01\x12\x0f\n\x07offsetZ\x18\x03 \x02(\x01\x12\x0f\n\x07offsetA\x18\x04 \x02(\x01\x12\x0f\n\x07offsetB\x18\x05 \x02(\x01\x12\x0f\n\x07offsetC\x18\x06 \x02(\x01\"\x82\x01\n\x0c\x43\x61rtWaypoint\x12$\n\x04pose\x18\x01 \x02(\x0b\x32\x16.motion_spec.CartPose6\x12\x33\n\nconstraint\x18\x02 \x01(\x0b\x32\x1f.motion_spec.WayPointConstraint\x12\x17\n\x0fsegmentVelocity\x18\x03 \x01(\x01\"\x88\x01\n\rJointWaypoint\x12)\n\x04pose\x18\x01 \x02(\x0b\x32\x1b.motion_spec.JointPositions\x12\x33\n\nconstraint\x18\x02 \x01(\x0b\x32\x1f.motion_spec.WayPointConstraint\x12\x17\n\x0fsegmentVelocity\x18\x03 \x01(\x01\"\xdb\x01\n\x05MoveC\x12\x31\n\nconstraint\x18\x01 \x02(\x0b\x32\x1d.motion_spec.MotionConstraint\x12\x33\n\x0ereferenceJoint\x18\x02 \x02(\x0b\x32\x1b.motion_spec.JointPositions\x12,\n\twaypoints\x18\x03 \x03(\x0b\x32\x19.motion_spec.CartWaypoint\x12\r\n\x05\x61ngle\x18\x04 \x02(\x01\x12-\n\tuserframe\x18\x05 \x01(\x0e\x32\x1a.motion_spec.USERFRAMETYPE\"\xcc\x01\n\x05MoveL\x12\x31\n\nconstraint\x18\x01 \x02(\x0b\x32\x1d.motion_spec.MotionConstraint\x12\x33\n\x0ereferenceJoint\x18\x02 \x02(\x0b\x32\x1b.motion_spec.JointPositions\x12,\n\twaypoints\x18\x03 \x03(\x0b\x32\x19.motion_spec.CartWaypoint\x12-\n\tuserframe\x18\x05 \x01(\x0e\x32\x1a.motion_spec.USERFRAMETYPE\"i\n\x05MoveJ\x12\x31\n\nconstraint\x18\x01 \x02(\x0b\x32\x1d.motion_spec.MotionConstraint\x12-\n\twaypoints\x18\x02 \x03(\x0b\x32\x1a.motion_spec.JointWaypoint\"4\n\x03Set\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\x08\x12\x10\n\x08time_sec\x18\x03 \x01(\x01\"\x13\n\x03Get\x12\x0c\n\x04path\x18\x01 \x02(\t\"H\n\x04Wait\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x12\n\nerror_code\x18\x04 \x01(\r\"c\n\rMotionCommand\x12\n\n\x02id\x18\x01 \x02(\r\x12,\n\x0b\x63ommandtype\x18\x02 \x02(\x0e\x32\x17.motion_spec.MOTIONTYPE\x12\x18\n\x10\x63ommandarguments\x18\x03 \x02(\x0c\"Z\n\rMotionProgram\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\n\n\x02id\x18\x02 \x02(\r\x12/\n\x0b\x63ommandlist\x18\x03 \x03(\x0b\x32\x1a.motion_spec.MotionCommand\"\xf3\x01\n\x0b\x43\x61rtToJoint\x12(\n\x08\x63\x61rtpose\x18\x01 \x02(\x0b\x32\x16.motion_spec.CartPose6\x12.\n\tjointpose\x18\x02 \x02(\x0b\x32\x1b.motion_spec.JointPositions\x12\x31\n\nframe_type\x18\x03 \x02(\x0e\x32\x1d.motion_spec.FEATUREFRAMETYPE\x12\x30\n\njointtwist\x18\x04 \x02(\x0b\x32\x1c.motion_spec.JointVelocities\x12%\n\tcarttwist\x18\x05 \x02(\x0b\x32\x12.motion_spec.Twist\"D\n\x0f\x43\x61rtToJointList\x12\x31\n\x0f\x63\x61rttojointlist\x18\x01 \x03(\x0b\x32\x18.motion_spec.CartToJoint\"\xc0\x01\n\x0bJointToCart\x12(\n\x08\x63\x61rtpose\x18\x01 \x02(\x0b\x32\x16.motion_spec.CartPose6\x12.\n\tjointpose\x18\x02 \x02(\x0b\x32\x1b.motion_spec.JointPositions\x12\x30\n\njointtwist\x18\x03 \x02(\x0b\x32\x1c.motion_spec.JointVelocities\x12%\n\tcarttwist\x18\x04 \x02(\x0b\x32\x12.motion_spec.Twist\"D\n\x0fJointToCartList\x12\x31\n\x0fjointtocartlist\x18\x01 \x03(\x0b\x32\x18.motion_spec.JointToCart*I\n\nMOTIONTYPE\x12\x0f\n\x0bJOINTMOTION\x10\x00\x12\x0e\n\nCARTMOTION\x10\x01\x12\x07\n\x03SET\x10\x02\x12\x08\n\x04WAIT\x10\x03\x12\x07\n\x03\x41RC\x10\x04*\x80\x01\n\rUSERFRAMETYPE\x12\t\n\x05ROBOT\x10\x00\x12\x07\n\x03UF1\x10\x01\x12\x07\n\x03UF2\x10\x02\x12\x07\n\x03UF3\x10\x03\x12\x07\n\x03UF4\x10\x04\x12\x07\n\x03UF5\x10\x05\x12\x07\n\x03UF6\x10\x06\x12\x07\n\x03UF7\x10\x07\x12\x07\n\x03UF8\x10\x08\x12\x07\n\x03UF9\x10\t\x12\x08\n\x04UF10\x10\n\x12\t\n\x05WORLD\x10\x64*B\n\x16WAYPOINTCONSTRAINTTYPE\x12\x0c\n\x08POSITION\x10\x00\x12\x08\n\x04TIME\x10\x01\x12\x10\n\x0c\x41\x43\x43\x45LERATION\x10\x02*I\n\x14MOTIONCONSTRAINTTYPE\x12\x0e\n\nTIMEANDACC\x10\x00\x12\x12\n\x0eTIMEANDTIMEACC\x10\x01\x12\r\n\tVELANDACC\x10\x02*+\n\x10\x46\x45\x41TUREFRAMETYPE\x12\n\n\x06\x46LANGE\x10\x00\x12\x0b\n\x07TOOLTIP\x10\x01')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_MOTIONTYPE = _descriptor.EnumDescriptor(
  name='MOTIONTYPE',
  full_name='motion_spec.MOTIONTYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='JOINTMOTION', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARTMOTION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAIT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARC', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2678,
  serialized_end=2751,
)
_sym_db.RegisterEnumDescriptor(_MOTIONTYPE)

MOTIONTYPE = enum_type_wrapper.EnumTypeWrapper(_MOTIONTYPE)
_USERFRAMETYPE = _descriptor.EnumDescriptor(
  name='USERFRAMETYPE',
  full_name='motion_spec.USERFRAMETYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROBOT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF1', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF2', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF3', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF4', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF5', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF6', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF7', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF8', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF9', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UF10', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORLD', index=11, number=100,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2754,
  serialized_end=2882,
)
_sym_db.RegisterEnumDescriptor(_USERFRAMETYPE)

USERFRAMETYPE = enum_type_wrapper.EnumTypeWrapper(_USERFRAMETYPE)
_WAYPOINTCONSTRAINTTYPE = _descriptor.EnumDescriptor(
  name='WAYPOINTCONSTRAINTTYPE',
  full_name='motion_spec.WAYPOINTCONSTRAINTTYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POSITION', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCELERATION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2884,
  serialized_end=2950,
)
_sym_db.RegisterEnumDescriptor(_WAYPOINTCONSTRAINTTYPE)

WAYPOINTCONSTRAINTTYPE = enum_type_wrapper.EnumTypeWrapper(_WAYPOINTCONSTRAINTTYPE)
_MOTIONCONSTRAINTTYPE = _descriptor.EnumDescriptor(
  name='MOTIONCONSTRAINTTYPE',
  full_name='motion_spec.MOTIONCONSTRAINTTYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIMEANDACC', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMEANDTIMEACC', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELANDACC', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2952,
  serialized_end=3025,
)
_sym_db.RegisterEnumDescriptor(_MOTIONCONSTRAINTTYPE)

MOTIONCONSTRAINTTYPE = enum_type_wrapper.EnumTypeWrapper(_MOTIONCONSTRAINTTYPE)
_FEATUREFRAMETYPE = _descriptor.EnumDescriptor(
  name='FEATUREFRAMETYPE',
  full_name='motion_spec.FEATUREFRAMETYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLANGE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOOLTIP', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3027,
  serialized_end=3070,
)
_sym_db.RegisterEnumDescriptor(_FEATUREFRAMETYPE)

FEATUREFRAMETYPE = enum_type_wrapper.EnumTypeWrapper(_FEATUREFRAMETYPE)
JOINTMOTION = 0
CARTMOTION = 1
SET = 2
WAIT = 3
ARC = 4
ROBOT = 0
UF1 = 1
UF2 = 2
UF3 = 3
UF4 = 4
UF5 = 5
UF6 = 6
UF7 = 7
UF8 = 8
UF9 = 9
UF10 = 10
WORLD = 100
POSITION = 0
TIME = 1
ACCELERATION = 2
TIMEANDACC = 0
TIMEANDTIMEACC = 1
VELANDACC = 2
FLANGE = 0
TOOLTIP = 1



_VELANDACCCONSTRAINTVALUES = _descriptor.Descriptor(
  name='VelAndAccConstraintValues',
  full_name='motion_spec.VelAndAccConstraintValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vMax', full_name='motion_spec.VelAndAccConstraintValues.vMax', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aMax', full_name='motion_spec.VelAndAccConstraintValues.aMax', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='omegaMax', full_name='motion_spec.VelAndAccConstraintValues.omegaMax', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alfaMax', full_name='motion_spec.VelAndAccConstraintValues.alfaMax', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jMax', full_name='motion_spec.VelAndAccConstraintValues.jMax', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=135,
)


_TIMEANDACCCONSTRAINTVALUES = _descriptor.Descriptor(
  name='TimeAndAccConstraintValues',
  full_name='motion_spec.TimeAndAccConstraintValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='T_duration', full_name='motion_spec.TimeAndAccConstraintValues.T_duration', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aMax', full_name='motion_spec.TimeAndAccConstraintValues.aMax', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=199,
)


_TIMEANDTIMEACCCONSTRAINTVALUES = _descriptor.Descriptor(
  name='TimeAndTimeAccConstraintValues',
  full_name='motion_spec.TimeAndTimeAccConstraintValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='T_duration', full_name='motion_spec.TimeAndTimeAccConstraintValues.T_duration', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='T_acc', full_name='motion_spec.TimeAndTimeAccConstraintValues.T_acc', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=268,
)


_MOTIONCONSTRAINT = _descriptor.Descriptor(
  name='MotionConstraint',
  full_name='motion_spec.MotionConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='motion_spec.MotionConstraint.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_values', full_name='motion_spec.MotionConstraint.time_values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeacc_values', full_name='motion_spec.MotionConstraint.timeacc_values', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velacc_values', full_name='motion_spec.MotionConstraint.velacc_values', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=532,
)


_WAYPOINTCONSTRAINT = _descriptor.Descriptor(
  name='WayPointConstraint',
  full_name='motion_spec.WayPointConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='motion_spec.WayPointConstraint.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='factor', full_name='motion_spec.WayPointConstraint.factor', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=534,
  serialized_end=621,
)


_CARTPOSE6 = _descriptor.Descriptor(
  name='CartPose6',
  full_name='motion_spec.CartPose6',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='motion_spec.CartPose6.coordinates', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='motion_spec.CartPose6.id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id_parent', full_name='motion_spec.CartPose6.id_parent', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=623,
  serialized_end=686,
)


_TWIST = _descriptor.Descriptor(
  name='Twist',
  full_name='motion_spec.Twist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='motion_spec.Twist.coordinates', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=716,
)


_JOINTPOSITIONS = _descriptor.Descriptor(
  name='JointPositions',
  full_name='motion_spec.JointPositions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='motion_spec.JointPositions.coordinates', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='motion_spec.JointPositions.id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id_parent', full_name='motion_spec.JointPositions.id_parent', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=786,
)


_JOINTVELOCITIES = _descriptor.Descriptor(
  name='JointVelocities',
  full_name='motion_spec.JointVelocities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='motion_spec.JointVelocities.coordinates', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=826,
)


_TOOLTIPOFFSET = _descriptor.Descriptor(
  name='ToolTipOffset',
  full_name='motion_spec.ToolTipOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offsetX', full_name='motion_spec.ToolTipOffset.offsetX', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offsetY', full_name='motion_spec.ToolTipOffset.offsetY', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offsetZ', full_name='motion_spec.ToolTipOffset.offsetZ', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offsetA', full_name='motion_spec.ToolTipOffset.offsetA', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offsetB', full_name='motion_spec.ToolTipOffset.offsetB', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offsetC', full_name='motion_spec.ToolTipOffset.offsetC', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=828,
  serialized_end=945,
)


_CARTWAYPOINT = _descriptor.Descriptor(
  name='CartWaypoint',
  full_name='motion_spec.CartWaypoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='motion_spec.CartWaypoint.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='constraint', full_name='motion_spec.CartWaypoint.constraint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='segmentVelocity', full_name='motion_spec.CartWaypoint.segmentVelocity', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1078,
)


_JOINTWAYPOINT = _descriptor.Descriptor(
  name='JointWaypoint',
  full_name='motion_spec.JointWaypoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='motion_spec.JointWaypoint.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='constraint', full_name='motion_spec.JointWaypoint.constraint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='segmentVelocity', full_name='motion_spec.JointWaypoint.segmentVelocity', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1217,
)


_MOVEC = _descriptor.Descriptor(
  name='MoveC',
  full_name='motion_spec.MoveC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='constraint', full_name='motion_spec.MoveC.constraint', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='referenceJoint', full_name='motion_spec.MoveC.referenceJoint', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='waypoints', full_name='motion_spec.MoveC.waypoints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angle', full_name='motion_spec.MoveC.angle', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userframe', full_name='motion_spec.MoveC.userframe', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1220,
  serialized_end=1439,
)


_MOVEL = _descriptor.Descriptor(
  name='MoveL',
  full_name='motion_spec.MoveL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='constraint', full_name='motion_spec.MoveL.constraint', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='referenceJoint', full_name='motion_spec.MoveL.referenceJoint', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='waypoints', full_name='motion_spec.MoveL.waypoints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userframe', full_name='motion_spec.MoveL.userframe', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1442,
  serialized_end=1646,
)


_MOVEJ = _descriptor.Descriptor(
  name='MoveJ',
  full_name='motion_spec.MoveJ',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='constraint', full_name='motion_spec.MoveJ.constraint', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='waypoints', full_name='motion_spec.MoveJ.waypoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1648,
  serialized_end=1753,
)


_SET = _descriptor.Descriptor(
  name='Set',
  full_name='motion_spec.Set',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='motion_spec.Set.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='motion_spec.Set.value', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_sec', full_name='motion_spec.Set.time_sec', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1755,
  serialized_end=1807,
)


_GET = _descriptor.Descriptor(
  name='Get',
  full_name='motion_spec.Get',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='motion_spec.Get.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=1828,
)


_WAIT = _descriptor.Descriptor(
  name='Wait',
  full_name='motion_spec.Wait',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='motion_spec.Wait.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='motion_spec.Wait.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='motion_spec.Wait.timeout', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='motion_spec.Wait.error_code', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1830,
  serialized_end=1902,
)


_MOTIONCOMMAND = _descriptor.Descriptor(
  name='MotionCommand',
  full_name='motion_spec.MotionCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='motion_spec.MotionCommand.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commandtype', full_name='motion_spec.MotionCommand.commandtype', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commandarguments', full_name='motion_spec.MotionCommand.commandarguments', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1904,
  serialized_end=2003,
)


_MOTIONPROGRAM = _descriptor.Descriptor(
  name='MotionProgram',
  full_name='motion_spec.MotionProgram',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='motion_spec.MotionProgram.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='motion_spec.MotionProgram.id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commandlist', full_name='motion_spec.MotionProgram.commandlist', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2095,
)


_CARTTOJOINT = _descriptor.Descriptor(
  name='CartToJoint',
  full_name='motion_spec.CartToJoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cartpose', full_name='motion_spec.CartToJoint.cartpose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jointpose', full_name='motion_spec.CartToJoint.jointpose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frame_type', full_name='motion_spec.CartToJoint.frame_type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jointtwist', full_name='motion_spec.CartToJoint.jointtwist', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='carttwist', full_name='motion_spec.CartToJoint.carttwist', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2098,
  serialized_end=2341,
)


_CARTTOJOINTLIST = _descriptor.Descriptor(
  name='CartToJointList',
  full_name='motion_spec.CartToJointList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='carttojointlist', full_name='motion_spec.CartToJointList.carttojointlist', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2343,
  serialized_end=2411,
)


_JOINTTOCART = _descriptor.Descriptor(
  name='JointToCart',
  full_name='motion_spec.JointToCart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cartpose', full_name='motion_spec.JointToCart.cartpose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jointpose', full_name='motion_spec.JointToCart.jointpose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='jointtwist', full_name='motion_spec.JointToCart.jointtwist', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='carttwist', full_name='motion_spec.JointToCart.carttwist', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2414,
  serialized_end=2606,
)


_JOINTTOCARTLIST = _descriptor.Descriptor(
  name='JointToCartList',
  full_name='motion_spec.JointToCartList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jointtocartlist', full_name='motion_spec.JointToCartList.jointtocartlist', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2608,
  serialized_end=2676,
)

_MOTIONCONSTRAINT.fields_by_name['type'].enum_type = _MOTIONCONSTRAINTTYPE
_MOTIONCONSTRAINT.fields_by_name['time_values'].message_type = _TIMEANDTIMEACCCONSTRAINTVALUES
_MOTIONCONSTRAINT.fields_by_name['timeacc_values'].message_type = _TIMEANDACCCONSTRAINTVALUES
_MOTIONCONSTRAINT.fields_by_name['velacc_values'].message_type = _VELANDACCCONSTRAINTVALUES
_WAYPOINTCONSTRAINT.fields_by_name['type'].enum_type = _WAYPOINTCONSTRAINTTYPE
_CARTWAYPOINT.fields_by_name['pose'].message_type = _CARTPOSE6
_CARTWAYPOINT.fields_by_name['constraint'].message_type = _WAYPOINTCONSTRAINT
_JOINTWAYPOINT.fields_by_name['pose'].message_type = _JOINTPOSITIONS
_JOINTWAYPOINT.fields_by_name['constraint'].message_type = _WAYPOINTCONSTRAINT
_MOVEC.fields_by_name['constraint'].message_type = _MOTIONCONSTRAINT
_MOVEC.fields_by_name['referenceJoint'].message_type = _JOINTPOSITIONS
_MOVEC.fields_by_name['waypoints'].message_type = _CARTWAYPOINT
_MOVEC.fields_by_name['userframe'].enum_type = _USERFRAMETYPE
_MOVEL.fields_by_name['constraint'].message_type = _MOTIONCONSTRAINT
_MOVEL.fields_by_name['referenceJoint'].message_type = _JOINTPOSITIONS
_MOVEL.fields_by_name['waypoints'].message_type = _CARTWAYPOINT
_MOVEL.fields_by_name['userframe'].enum_type = _USERFRAMETYPE
_MOVEJ.fields_by_name['constraint'].message_type = _MOTIONCONSTRAINT
_MOVEJ.fields_by_name['waypoints'].message_type = _JOINTWAYPOINT
_MOTIONCOMMAND.fields_by_name['commandtype'].enum_type = _MOTIONTYPE
_MOTIONPROGRAM.fields_by_name['commandlist'].message_type = _MOTIONCOMMAND
_CARTTOJOINT.fields_by_name['cartpose'].message_type = _CARTPOSE6
_CARTTOJOINT.fields_by_name['jointpose'].message_type = _JOINTPOSITIONS
_CARTTOJOINT.fields_by_name['frame_type'].enum_type = _FEATUREFRAMETYPE
_CARTTOJOINT.fields_by_name['jointtwist'].message_type = _JOINTVELOCITIES
_CARTTOJOINT.fields_by_name['carttwist'].message_type = _TWIST
_CARTTOJOINTLIST.fields_by_name['carttojointlist'].message_type = _CARTTOJOINT
_JOINTTOCART.fields_by_name['cartpose'].message_type = _CARTPOSE6
_JOINTTOCART.fields_by_name['jointpose'].message_type = _JOINTPOSITIONS
_JOINTTOCART.fields_by_name['jointtwist'].message_type = _JOINTVELOCITIES
_JOINTTOCART.fields_by_name['carttwist'].message_type = _TWIST
_JOINTTOCARTLIST.fields_by_name['jointtocartlist'].message_type = _JOINTTOCART
DESCRIPTOR.message_types_by_name['VelAndAccConstraintValues'] = _VELANDACCCONSTRAINTVALUES
DESCRIPTOR.message_types_by_name['TimeAndAccConstraintValues'] = _TIMEANDACCCONSTRAINTVALUES
DESCRIPTOR.message_types_by_name['TimeAndTimeAccConstraintValues'] = _TIMEANDTIMEACCCONSTRAINTVALUES
DESCRIPTOR.message_types_by_name['MotionConstraint'] = _MOTIONCONSTRAINT
DESCRIPTOR.message_types_by_name['WayPointConstraint'] = _WAYPOINTCONSTRAINT
DESCRIPTOR.message_types_by_name['CartPose6'] = _CARTPOSE6
DESCRIPTOR.message_types_by_name['Twist'] = _TWIST
DESCRIPTOR.message_types_by_name['JointPositions'] = _JOINTPOSITIONS
DESCRIPTOR.message_types_by_name['JointVelocities'] = _JOINTVELOCITIES
DESCRIPTOR.message_types_by_name['ToolTipOffset'] = _TOOLTIPOFFSET
DESCRIPTOR.message_types_by_name['CartWaypoint'] = _CARTWAYPOINT
DESCRIPTOR.message_types_by_name['JointWaypoint'] = _JOINTWAYPOINT
DESCRIPTOR.message_types_by_name['MoveC'] = _MOVEC
DESCRIPTOR.message_types_by_name['MoveL'] = _MOVEL
DESCRIPTOR.message_types_by_name['MoveJ'] = _MOVEJ
DESCRIPTOR.message_types_by_name['Set'] = _SET
DESCRIPTOR.message_types_by_name['Get'] = _GET
DESCRIPTOR.message_types_by_name['Wait'] = _WAIT
DESCRIPTOR.message_types_by_name['MotionCommand'] = _MOTIONCOMMAND
DESCRIPTOR.message_types_by_name['MotionProgram'] = _MOTIONPROGRAM
DESCRIPTOR.message_types_by_name['CartToJoint'] = _CARTTOJOINT
DESCRIPTOR.message_types_by_name['CartToJointList'] = _CARTTOJOINTLIST
DESCRIPTOR.message_types_by_name['JointToCart'] = _JOINTTOCART
DESCRIPTOR.message_types_by_name['JointToCartList'] = _JOINTTOCARTLIST
DESCRIPTOR.enum_types_by_name['MOTIONTYPE'] = _MOTIONTYPE
DESCRIPTOR.enum_types_by_name['USERFRAMETYPE'] = _USERFRAMETYPE
DESCRIPTOR.enum_types_by_name['WAYPOINTCONSTRAINTTYPE'] = _WAYPOINTCONSTRAINTTYPE
DESCRIPTOR.enum_types_by_name['MOTIONCONSTRAINTTYPE'] = _MOTIONCONSTRAINTTYPE
DESCRIPTOR.enum_types_by_name['FEATUREFRAMETYPE'] = _FEATUREFRAMETYPE

VelAndAccConstraintValues = _reflection.GeneratedProtocolMessageType('VelAndAccConstraintValues', (_message.Message,), dict(
  DESCRIPTOR = _VELANDACCCONSTRAINTVALUES,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.VelAndAccConstraintValues)
  ))
_sym_db.RegisterMessage(VelAndAccConstraintValues)

TimeAndAccConstraintValues = _reflection.GeneratedProtocolMessageType('TimeAndAccConstraintValues', (_message.Message,), dict(
  DESCRIPTOR = _TIMEANDACCCONSTRAINTVALUES,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.TimeAndAccConstraintValues)
  ))
_sym_db.RegisterMessage(TimeAndAccConstraintValues)

TimeAndTimeAccConstraintValues = _reflection.GeneratedProtocolMessageType('TimeAndTimeAccConstraintValues', (_message.Message,), dict(
  DESCRIPTOR = _TIMEANDTIMEACCCONSTRAINTVALUES,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.TimeAndTimeAccConstraintValues)
  ))
_sym_db.RegisterMessage(TimeAndTimeAccConstraintValues)

MotionConstraint = _reflection.GeneratedProtocolMessageType('MotionConstraint', (_message.Message,), dict(
  DESCRIPTOR = _MOTIONCONSTRAINT,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.MotionConstraint)
  ))
_sym_db.RegisterMessage(MotionConstraint)

WayPointConstraint = _reflection.GeneratedProtocolMessageType('WayPointConstraint', (_message.Message,), dict(
  DESCRIPTOR = _WAYPOINTCONSTRAINT,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.WayPointConstraint)
  ))
_sym_db.RegisterMessage(WayPointConstraint)

CartPose6 = _reflection.GeneratedProtocolMessageType('CartPose6', (_message.Message,), dict(
  DESCRIPTOR = _CARTPOSE6,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.CartPose6)
  ))
_sym_db.RegisterMessage(CartPose6)

Twist = _reflection.GeneratedProtocolMessageType('Twist', (_message.Message,), dict(
  DESCRIPTOR = _TWIST,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.Twist)
  ))
_sym_db.RegisterMessage(Twist)

JointPositions = _reflection.GeneratedProtocolMessageType('JointPositions', (_message.Message,), dict(
  DESCRIPTOR = _JOINTPOSITIONS,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.JointPositions)
  ))
_sym_db.RegisterMessage(JointPositions)

JointVelocities = _reflection.GeneratedProtocolMessageType('JointVelocities', (_message.Message,), dict(
  DESCRIPTOR = _JOINTVELOCITIES,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.JointVelocities)
  ))
_sym_db.RegisterMessage(JointVelocities)

ToolTipOffset = _reflection.GeneratedProtocolMessageType('ToolTipOffset', (_message.Message,), dict(
  DESCRIPTOR = _TOOLTIPOFFSET,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.ToolTipOffset)
  ))
_sym_db.RegisterMessage(ToolTipOffset)

CartWaypoint = _reflection.GeneratedProtocolMessageType('CartWaypoint', (_message.Message,), dict(
  DESCRIPTOR = _CARTWAYPOINT,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.CartWaypoint)
  ))
_sym_db.RegisterMessage(CartWaypoint)

JointWaypoint = _reflection.GeneratedProtocolMessageType('JointWaypoint', (_message.Message,), dict(
  DESCRIPTOR = _JOINTWAYPOINT,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.JointWaypoint)
  ))
_sym_db.RegisterMessage(JointWaypoint)

MoveC = _reflection.GeneratedProtocolMessageType('MoveC', (_message.Message,), dict(
  DESCRIPTOR = _MOVEC,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.MoveC)
  ))
_sym_db.RegisterMessage(MoveC)

MoveL = _reflection.GeneratedProtocolMessageType('MoveL', (_message.Message,), dict(
  DESCRIPTOR = _MOVEL,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.MoveL)
  ))
_sym_db.RegisterMessage(MoveL)

MoveJ = _reflection.GeneratedProtocolMessageType('MoveJ', (_message.Message,), dict(
  DESCRIPTOR = _MOVEJ,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.MoveJ)
  ))
_sym_db.RegisterMessage(MoveJ)

Set = _reflection.GeneratedProtocolMessageType('Set', (_message.Message,), dict(
  DESCRIPTOR = _SET,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.Set)
  ))
_sym_db.RegisterMessage(Set)

Get = _reflection.GeneratedProtocolMessageType('Get', (_message.Message,), dict(
  DESCRIPTOR = _GET,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.Get)
  ))
_sym_db.RegisterMessage(Get)

Wait = _reflection.GeneratedProtocolMessageType('Wait', (_message.Message,), dict(
  DESCRIPTOR = _WAIT,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.Wait)
  ))
_sym_db.RegisterMessage(Wait)

MotionCommand = _reflection.GeneratedProtocolMessageType('MotionCommand', (_message.Message,), dict(
  DESCRIPTOR = _MOTIONCOMMAND,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.MotionCommand)
  ))
_sym_db.RegisterMessage(MotionCommand)

MotionProgram = _reflection.GeneratedProtocolMessageType('MotionProgram', (_message.Message,), dict(
  DESCRIPTOR = _MOTIONPROGRAM,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.MotionProgram)
  ))
_sym_db.RegisterMessage(MotionProgram)

CartToJoint = _reflection.GeneratedProtocolMessageType('CartToJoint', (_message.Message,), dict(
  DESCRIPTOR = _CARTTOJOINT,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.CartToJoint)
  ))
_sym_db.RegisterMessage(CartToJoint)

CartToJointList = _reflection.GeneratedProtocolMessageType('CartToJointList', (_message.Message,), dict(
  DESCRIPTOR = _CARTTOJOINTLIST,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.CartToJointList)
  ))
_sym_db.RegisterMessage(CartToJointList)

JointToCart = _reflection.GeneratedProtocolMessageType('JointToCart', (_message.Message,), dict(
  DESCRIPTOR = _JOINTTOCART,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.JointToCart)
  ))
_sym_db.RegisterMessage(JointToCart)

JointToCartList = _reflection.GeneratedProtocolMessageType('JointToCartList', (_message.Message,), dict(
  DESCRIPTOR = _JOINTTOCARTLIST,
  __module__ = 'motionSL_pb2'
  # @@protoc_insertion_point(class_scope:motion_spec.JointToCartList)
  ))
_sym_db.RegisterMessage(JointToCartList)


# @@protoc_insertion_point(module_scope)
